@@ -23,7 +23,9 @@
 #error "only <libtracker-sparql/tracker-sparql.h> must be included directly."
 #endif
 
+#include <libtracker-sparql/tracker-error.h>
 #include <libtracker-sparql/tracker-notifier.h>
+#include <libtracker-sparql/tracker-resource.h>
 #include <libtracker-sparql/tracker-version.h>
 #include <gio/gio.h>
 
@@ -62,62 +64,11 @@ G_DECLARE_DERIVABLE_TYPE (TrackerSparqlConnection,
                           TRACKER, SPARQL_CONNECTION,
                           GObject)
 
+#include "tracker-batch.h"
 #include "tracker-cursor.h"
 #include "tracker-statement.h"
 #include "tracker-namespace-manager.h"
 
-/**
- * TrackerSparqlError:
- * @TRACKER_SPARQL_ERROR_PARSE: Error parsing the SPARQL string.
- * @TRACKER_SPARQL_ERROR_UNKNOWN_CLASS: Unknown class.
- * @TRACKER_SPARQL_ERROR_UNKNOWN_PROPERTY: Unknown property.
- * @TRACKER_SPARQL_ERROR_TYPE: Wrong type.
- * @TRACKER_SPARQL_ERROR_CONSTRAINT: Subject is not in the domain of a property or
- *                             trying to set multiple values for a single valued
- *                             property.
- * @TRACKER_SPARQL_ERROR_NO_SPACE: There was no disk space available to perform the request.
- * @TRACKER_SPARQL_ERROR_INTERNAL: Internal error.
- * @TRACKER_SPARQL_ERROR_UNSUPPORTED: Unsupported feature or method.
- * @TRACKER_SPARQL_ERROR_UNKNOWN_GRAPH: Unknown graph.
- * @TRACKER_SPARQL_ERROR_ONTOLOGY_NOT_FOUND: The specified ontology wasn't found.
- * @TRACKER_SPARQL_N_ERRORS: The total number of error codes.
- *
- * Error domain for Tracker Sparql. Errors in this domain will be from the
- * #TrackerSparqlError enumeration. See #GError for more information on error
- * domains.
- */
-typedef enum {
-	TRACKER_SPARQL_ERROR_PARSE,
-	TRACKER_SPARQL_ERROR_UNKNOWN_CLASS,
-	TRACKER_SPARQL_ERROR_UNKNOWN_PROPERTY,
-	TRACKER_SPARQL_ERROR_TYPE,
-	TRACKER_SPARQL_ERROR_CONSTRAINT,
-	TRACKER_SPARQL_ERROR_NO_SPACE,
-	TRACKER_SPARQL_ERROR_INTERNAL,
-	TRACKER_SPARQL_ERROR_UNSUPPORTED,
-	TRACKER_SPARQL_ERROR_UNKNOWN_GRAPH,
-	TRACKER_SPARQL_ERROR_ONTOLOGY_NOT_FOUND,
-	TRACKER_SPARQL_N_ERRORS,
-} TrackerSparqlError;
-
-static const GDBusErrorEntry tracker_sparql_error_entries[] =
-{
-	{TRACKER_SPARQL_ERROR_PARSE, "org.freedesktop.Tracker.Error.Parse"},
-	{TRACKER_SPARQL_ERROR_UNKNOWN_CLASS, "org.freedesktop.Tracker.Error.UnknownClass"},
-	{TRACKER_SPARQL_ERROR_UNKNOWN_PROPERTY, "org.freedesktop.Tracker.Error.UnknownProperty"},
-	{TRACKER_SPARQL_ERROR_TYPE, "org.freedesktop.Tracker.Error.Type"},
-	{TRACKER_SPARQL_ERROR_CONSTRAINT, "org.freedesktop.Tracker.Error.Constraint"},
-	{TRACKER_SPARQL_ERROR_NO_SPACE, "org.freedesktop.Tracker.Error.NoSpace"},
-	{TRACKER_SPARQL_ERROR_INTERNAL, "org.freedesktop.Tracker.Error.Internal"},
-	{TRACKER_SPARQL_ERROR_UNSUPPORTED, "org.freedesktop.Tracker.Error.Unsupported"},
-	{TRACKER_SPARQL_ERROR_UNKNOWN_GRAPH, "org.freedesktop.Tracker.Error.UnknownGraph"},
-	{TRACKER_SPARQL_ERROR_ONTOLOGY_NOT_FOUND, "org.freedesktop.Tracker.Error.OntologyNotFound"},
-};
-
-#define TRACKER_SPARQL_ERROR tracker_sparql_error_quark ()
-
-TRACKER_AVAILABLE_IN_ALL
-GQuark tracker_sparql_error_quark (void);
 
 TRACKER_AVAILABLE_IN_ALL
 TrackerSparqlConnection * tracker_sparql_connection_new (TrackerSparqlConnectionFlags   flags,
@@ -141,6 +92,17 @@ TrackerSparqlConnection * tracker_sparql_connection_bus_new (const gchar      *s
                                                              const gchar      *object_path,
                                                              GDBusConnection  *dbus_connection,
                                                              GError          **error);
+TRACKER_AVAILABLE_IN_3_1
+void tracker_sparql_connection_bus_new_async (const gchar         *service_name,
+                                              const gchar         *object_path,
+                                              GDBusConnection     *dbus_connection,
+                                              GCancellable        *cancellable,
+                                              GAsyncReadyCallback  callback,
+                                              gpointer             user_data);
+TRACKER_AVAILABLE_IN_3_1
+TrackerSparqlConnection * tracker_sparql_connection_bus_new_finish (GAsyncResult  *result,
+                                                                    GError       **error);
+
 TRACKER_AVAILABLE_IN_ALL
 TrackerSparqlConnection * tracker_sparql_connection_remote_new (const gchar *uri_base);
 
@@ -187,6 +149,26 @@ TRACKER_AVAILABLE_IN_ALL
 gboolean tracker_sparql_connection_update_array_finish (TrackerSparqlConnection  *connection,
                                                         GAsyncResult             *res,
                                                         GError                  **error);
+TRACKER_AVAILABLE_IN_3_1
+gboolean tracker_sparql_connection_update_resource (TrackerSparqlConnection  *connection,
+                                                    const gchar              *graph,
+                                                    TrackerResource          *resource,
+                                                    GCancellable             *cancellable,
+                                                    GError                  **error);
+TRACKER_AVAILABLE_IN_3_1
+void tracker_sparql_connection_update_resource_async (TrackerSparqlConnection *connection,
+                                                      const gchar             *graph,
+                                                      TrackerResource         *resource,
+                                                      GCancellable            *cancellable,
+                                                      GAsyncReadyCallback      callback,
+                                                      gpointer                 user_data);
+TRACKER_AVAILABLE_IN_3_1
+gboolean tracker_sparql_connection_update_resource_finish (TrackerSparqlConnection  *connection,
+                                                           GAsyncResult             *res,
+                                                           GError                  **error);
+TRACKER_AVAILABLE_IN_3_1
+TrackerBatch * tracker_sparql_connection_create_batch (TrackerSparqlConnection *connection);
+
 TRACKER_AVAILABLE_IN_ALL
 GVariant * tracker_sparql_connection_update_blank (TrackerSparqlConnection  *connection,
                                                    const gchar              *sparql,
